package simplebattleship;

import java.util.Random;


public class Game 
{
	private Board _board;
	
	
	private int _shipsAlive;
	private int _boardSize;
	private int _attemptsCounter;
	private GameUI _viewer;
	
	public Game(int boardSize, int maxShips)
	{
		_board=new Board(boardSize,maxShips);
		_boardSize=boardSize;
		
		_viewer=new GameUI(_board, _boardSize);
		
		//start placing ships on the board
		int shipsCreated=0;
		Random rand = new Random();

		while(shipsCreated<maxShips)
		{
			int nextShipStart=rand.nextInt(boardSize);
			if(_board.addShip(nextShipStart,shipsCreated))
				shipsCreated++;				
		}	
		_shipsAlive=maxShips;
	}
	
	public void play()
	{
		while(_shipsAlive>0)
		{
			_viewer.displayBoard();
			int nextLocation=_viewer.getLocationFromUser();
			_attemptsCounter++;
			Result result=Result.MISS;
			Ship damagedShip=_board.getHit(nextLocation);
			if(damagedShip!=null)
			{
				Status shipStatus=damagedShip.getStatus();
				if(shipStatus==Status.SUNK)
				{
					_shipsAlive--;
					result=Result.KILL;
				}
				else
					result=Result.HIT;
			}
			_viewer.displayResult(result);
		}
		_viewer.displayBoard();
		_viewer.displayGameEnd(_attemptsCounter);
	}
	
	public static void main(String [] args)
	{
		if(args.length<2)
		{
			System.out.println("To run simpleshipsgame.Game <Board size> <Number of ships>");
			System.exit(0);
		}
		
		try
		{
			int boardSize=Integer.parseInt(args[0]);
			int maxShips=Integer.parseInt(args[1]);
			Game game=new Game(boardSize,maxShips);
			game.play();		
			
		}
		catch(NumberFormatException nfe)
		{
			System.out.println("Invalid arguments");
			System.exit(0);
		}
	}
}
